package controllers

import (
	"ERP_storage/Nats/NatsServer"
	"ERP_storage/dto"
	"ERP_storage/models/Account"
	"ERP_storage/services"
	userlibs "git.baozhida.cn/ERP_libs/User"
	"git.baozhida.cn/ERP_libs/lib"
	beego "github.com/beego/beego/v2/server/web"
	"math"
	"strconv"
)

type ContractReviewController struct {
	beego.Controller
	User userlibs.User
}

func (c *ContractReviewController) Prepare() {
	c.User = *Account.User_r
}

// 服务类型
func (c *ContractReviewController) ServiceType_List() {
	s := services.ServiceType{}
	reqData := dto.ServiceTypePageReq{}
	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	R_List, R_cnt := s.GetPage(&reqData)

	var r_jsons lib.R_JSONS
	r_jsons.Num = R_cnt
	r_jsons.Data = R_List
	r_jsons.Page = reqData.Page
	r_jsons.Page_size = int(math.Ceil(float64(R_cnt) / float64(reqData.PageSize)))

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!", Data: r_jsons}
	c.ServeJSON()
	return
}
func (c *ContractReviewController) ServiceType_Add() {
	s := services.ServiceType{}

	reqData := dto.ServiceTypeInsertReq{}

	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}
	Id, err := s.Insert(&reqData)
	if err != nil {
		c.Data["json"] = lib.JSONS{Code: 203, Msg: "添加失败"}
		c.ServeJSON()
		return
	}

	NatsServer.AddUserLogs(c.User.T_uuid, "服务类型", "添加", reqData)

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!", Data: Id}
	c.ServeJSON()
	return
}
func (c *ContractReviewController) ServiceType_Edit() {
	s := services.ServiceType{}
	reqData := dto.ServiceTypeUpdateReq{}
	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	if err := s.Update(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 203, Msg: "修改失败"}
		c.ServeJSON()
		return
	}

	NatsServer.AddUserLogs(c.User.T_uuid, "服务类型", "修改", reqData)

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!"}
	c.ServeJSON()
	return
}
func (c *ContractReviewController) ServiceType_Del() {
	s := services.ServiceType{}
	reqData := dto.ServiceTypeDeleteReq{}
	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	if err := s.Delete(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	NatsServer.AddUserLogs(c.User.T_uuid, "服务类型", "删除", strconv.Itoa(reqData.T_id))

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!"}
	c.ServeJSON()
	return
}

// 服务内容
func (c *ContractReviewController) ServiceItem_List() {
	s := services.ServiceItem{}
	reqData := dto.ServiceItemPageReq{}
	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	R_List, R_cnt := s.GetPage(&reqData)

	var r_jsons lib.R_JSONS
	r_jsons.Num = R_cnt
	r_jsons.Data = R_List
	r_jsons.Page = reqData.Page
	r_jsons.Page_size = int(math.Ceil(float64(R_cnt) / float64(reqData.PageSize)))

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!", Data: r_jsons}
	c.ServeJSON()
	return
}
func (c *ContractReviewController) ServiceItem_Add() {
	s := services.ServiceItem{}

	reqData := dto.ServiceItemInsertReq{}

	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}
	Id, err := s.Insert(&reqData)
	if err != nil {
		c.Data["json"] = lib.JSONS{Code: 203, Msg: "添加失败"}
		c.ServeJSON()
		return
	}

	NatsServer.AddUserLogs(c.User.T_uuid, "服务内容", "添加", reqData)

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!", Data: Id}
	c.ServeJSON()
	return
}
func (c *ContractReviewController) ServiceItem_Edit() {
	s := services.ServiceItem{}
	reqData := dto.ServiceItemUpdateReq{}
	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	if err := s.Update(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 203, Msg: "修改失败"}
		c.ServeJSON()
		return
	}

	NatsServer.AddUserLogs(c.User.T_uuid, "服务内容", "修改", reqData)

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!"}
	c.ServeJSON()
	return
}
func (c *ContractReviewController) ServiceItem_Del() {
	s := services.ServiceItem{}
	reqData := dto.ServiceItemDeleteReq{}
	if err := c.ParseForm(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "参数错误"}
		c.ServeJSON()
		return
	}
	if err := Validate(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: err.Error()}
		c.ServeJSON()
		return
	}

	if err := s.Delete(&reqData); err != nil {
		c.Data["json"] = lib.JSONS{Code: 202, Msg: "删除失败!"}
		c.ServeJSON()
		return
	}

	NatsServer.AddUserLogs(c.User.T_uuid, "服务内容", "删除", strconv.Itoa(reqData.T_id))

	c.Data["json"] = lib.JSONS{Code: 200, Msg: "ok!"}
	c.ServeJSON()
	return
}
